@@ -48,25 +48,25 @@ sub load_class {
 }
 
 sub get_class_name {
-    my ( $self, $name ) = @_;
-    my $namespace =
-        $self->parent_element
-      ? $self->parent_element->{classname}
-      : $self->namespace;
+    my ( $self, $el ) = @_;
+    my $name = $el->{LocalName};
+    my $namespace
+        = $self->parent_element
+        ? $self->parent_element->{classname}
+        : $self->namespace;
     return $namespace . '::' . ucfirst $name;
 }
-
 augment 'start_element' => sub {
     my ( $self, $el ) = @_;
 
-    my $classname = $self->get_class_name( $el->{Name} );
+    my $classname = $self->get_class_name( $el );
     $el->{classname} = $classname;
     my $class = $self->load_class($classname);
 
     return unless $class;
     my %params =
       map { $_->{Name} => $_->{Value} } values %{ $el->{Attributes} };
-
+    
     my $obj = $class->new(%params);
     $self->add_object($obj);
 };
@@ -96,4 +96,99 @@ sub render {
 
 no Moose;
 1;
-__END__
\ No newline at end of file
+
+__END__
+
+=head1 NAME
+
+XML::Toolkit::Loader::Parser - A class to ...
+
+=head1 VERSION
+
+This documentation refers to version 0.01.
+
+=head1 SYNOPSIS
+
+use XML::Toolkit::Loader::Parser;
+
+=head1 DESCRIPTION
+
+The XML::Toolkit::Loader::Parser class implements ...
+
+=head1 SUBROUTINES / METHODS
+
+=head2 parent_object (method)
+
+Parameters:
+    none
+
+Insert description of method here...
+
+=head2 current_object (method)
+
+Parameters:
+    none
+
+Insert description of method here...
+
+=head2 root_object (method)
+
+Parameters:
+    none
+
+Insert description of method here...
+
+=head2 load_class (method)
+
+Parameters:
+    name
+
+Insert description of method here...
+
+=head2 get_class_name (method)
+
+Parameters:
+    name
+    self
+    el
+    self
+    el
+
+Insert description of method here...
+
+=head2 render
+
+Parameters:
+    none
+
+Insert description of subroutine here...
+
+=head1 DEPENDENCIES
+
+Modules used, version dependencies, core yes/no
+
+Moose
+
+MooseX::AttributeHelpers
+
+Moose::Autobox
+
+=head1 NOTES
+
+...
+
+=head1 BUGS AND LIMITATIONS
+
+None known currently, please email the author if you find any.
+
+=head1 AUTHOR
+
+Chris Prather (perigrin@domain.tld)
+
+=head1 LICENCE
+
+Copyright 2009 by Chris Prather.
+
+This software is free.  It is licensed under the same terms as Perl itself.
+
+=cut
